﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Text.RegularExpressions;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;

namespace Ukazka2
{
    /// <summary>
    /// Interakční logika pro MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private bool inic = false;


        /// <summary>
        /// Konstruktor třídy
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            NaplnData();
            inic = true;
        }


        /// <summary>
        /// Naplnění prvků daty
        /// </summary>
        private void NaplnData()
        {
            // Naplnění ListBoxu
            lbxSeznam1.Items.Add("Položka 1");
            lbxSeznam1.Items.Add("Položka 2");
            lbxSeznam1.Items.Add("Položka 3");
            lbxSeznam1.Items.Add("Položka 4");
            lbxSeznam1.Items.Add("Položka 5");
            lbxSeznam1.Items.Add("Položka 6");
            lbxSeznam1.Items.Add("Položka 7");
            lbxSeznam1.Items.Add("Položka 8");
            lbxSeznam1.Items.Add("Položka 9");
            lbxSeznam1.Items.Add("Položka 10");

            // Naplnění ComboBoxu
            List<string> seznam = new List<string>();
            seznam.Add("Položka 1");
            seznam.Add("Položka 2");
            seznam.Add("Položka 3");
            seznam.Add("Položka 4");
            seznam.Add("Položka 5");
            seznam.Add("Položka 6");
            seznam.Add("Položka 7");
            seznam.Add("Položka 8");
            seznam.Add("Položka 9");
            seznam.Add("Položka 10");
            cbxVolba.ItemsSource = seznam;

            // Naplnění RichTextBoxu
            rtbText.Document.Blocks.Clear();
            using (Stream stream = System.Reflection.Assembly.GetExecutingAssembly().GetManifestResourceStream("Ukazka2.Resources.CvicnyText.rtf"))
            {
                TextRange range = new TextRange(rtbText.Document.ContentStart, rtbText.Document.ContentEnd);
                range.Load(stream, DataFormats.Rtf);
                stream.Close();
            }
        }


        /// <summary>
        /// Zavření okna
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ZavriOkno(object sender, RoutedEventArgs e)
        {
            wdwPrvky.Close();
        }



        #region "Prvky pro vkládání dat" ======================================
        /// <summary>
        /// Calendar - Zobrazení vybraného dne
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ZobrazDen(object sender, SelectionChangedEventArgs e)
        {
            DateTime pomDat = calKalendar.SelectedDate.Value;
            lblDen.Content = pomDat.ToShortDateString();
            Mouse.Capture(null); // tento příkaz odstraňuje nutnost dvojího kliknutí při změně focusu na jinou komponentu
        }


        /// <summary>
        /// Calendar - Zobrazení rozsahu dní
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ZobrazDen1(object sender, SelectionChangedEventArgs e)
        {
            Boolean poprve = true;
            foreach (DateTime pomDat in calKalendar1.SelectedDates)
            {
                if (poprve)
                {
                    lblDen1.Content = pomDat.ToString("dd");
                    poprve = false;
                }
                else
                {
                    lblDen1.Content += ". " + pomDat.ToString("dd");
                }
            }
            Mouse.Capture(null); // tento příkaz odstraňuje nutnost dvojího kliknutí při změně focusu na jinou komponentu
        }


        /// <summary>
        /// ComboBox - Zobrazení vybrané položky
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Volba(object sender, SelectionChangedEventArgs e)
        {
            if (inic)
            {
                ComboBox cbx = sender as ComboBox;
                lblVybranoCbx.Content = cbx.SelectedValue.ToString();
            }
        }


        /// <summary>
        /// DatePicker - Zobrazení vybraného dne
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ZobrazDatum(object sender, SelectionChangedEventArgs e)
        {
            DateTime pomDat = dprDatum.SelectedDate.Value;
            lblDatum.Content = pomDat.ToShortDateString();
        }


        /// <summary>
        /// TextBox - Vyčištění pole
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void VycistiPole(object sender, RoutedEventArgs e)
        {
            tbxPocet.Text = "";
        }


        /// <summary>
        /// TextBox - Povolení pouze číslic, čárky a tečky
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void KontrolaVstupu(object sender, TextCompositionEventArgs e)
        {
            Regex regex = new Regex("\\d|[,.]");
            e.Handled = !regex.IsMatch(e.Text);
        }

        
        /// <summary>
        /// ListBox - Vybraná položka
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Vybrano(object sender, SelectionChangedEventArgs e)
        {
            if (lbxSeznam.SelectedIndex > -1)
            {
                string vybrano = lbxSeznam.SelectedValue.ToString();
                vybrano = vybrano.Replace("System.Windows.Controls.ListBoxItem:", "");
                lblVybrano.Content = vybrano;
            }
        }


        /// <summary>
        /// ListBox - Počet vybraných položek
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Vybrano1(object sender, SelectionChangedEventArgs e)
        {
            int pocet = 0;
            foreach (string polozka in lbxSeznam1.SelectedItems)
            {
                pocet += 1;
            }
            lblVybrano1.Content = "Vybráno " + pocet.ToString() + " záznamů";
        }


        /// <summary>
        /// PasswordBox - Zobrazení hesla
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ZobrazHeslo(object sender, RoutedEventArgs e)
        {
            lblHeslo.Content = psbxHeslo.Password.ToString();
        }
        #endregion
    }
}
